@@ -9,7 +9,7 @@ import tempfile
 import subprocess
 from shutil import rmtree
 
-version = '20w53a'
+version = '21w01a'
 
 def file_type(file: str) -> str:
     if(not os.path.isfile(file)):
@@ -27,8 +27,19 @@ def sample_rate_type(num: str) -> int:
         return int(num[:-3])
     if(num.endswith(' kHz')):
         return int(float(num[:-4]) * 1000)
+    if(num.endswith('kHz')):
+        return int(float(num[:-3]) * 1000)
+    if(num.endswith('Hz')):
+        return int(num[:-2])
     return int(num)
 
+def frame_type(inp: str):
+    if(inp.endswith('sec')):
+        return inp[:-3]
+    if(inp.endswith('secs')):
+        return inp[:-4]
+    return int(inp)
+
 def add_argument(*names, nargs=1, type=str, default=None, action='default',
     range=None, choices=None, parent='auto-editor', help='', extra=''):
     newDic = {}
@@ -71,6 +82,8 @@ def main_options():
     ops += add_argument('--video_codec', '-vcodec', default='uncompressed',
         parent='exportMediaOps',
         help='set the video codec for the output media file.')
+    ops += add_argument('--audio_codec', '-acodec', parent='exportMediaOps',
+        help='set the audio codec for the output media file.')
     ops += add_argument('--preset', '-p', default='medium', parent='exportMediaOps',
         choices=['ultrafast', 'superfast', 'veryfast', 'faster', 'fast', 'medium',
             'slow', 'slower', 'veryslow'],
@@ -89,12 +102,11 @@ def main_options():
         help='set how many times a frame is dilated before being compared.')
     ops += add_argument('--width', '-w', type=int, default=400, range='1 to Infinity',
         parent='motionOps',
-        help="set the frame's new width (in pixels) before being compared.")
+        help="scale the frame to this width before being compared.")
     ops += add_argument('--blur', '-b', type=int, default=21, range='0 to Infinity',
         parent='motionOps',
         help='set the strength of the blur applied to a frame before being compared.')
 
-    # TODO: add export_as_video
     ops += add_argument('--export_as_audio', '-exa', action='store_true',
         help='export as a WAV audio file.')
     ops += add_argument('--export_to_premiere', '-exp', action='store_true',
@@ -142,10 +154,10 @@ def main_options():
 
     ops += add_argument('--no_open', action='store_true',
         help='do not open the file after editing is done.')
-    ops += add_argument('--min_clip_length', '-mclip', type=int, default=3,
+    ops += add_argument('--min_clip_length', '-mclip', type=frame_type, default=3,
         range='0 to Infinity',
         help='set the minimum length a clip can be. If a clip is too short, cut it.')
-    ops += add_argument('--min_cut_length', '-mcut', type=int, default=6,
+    ops += add_argument('--min_cut_length', '-mcut', type=frame_type, default=6,
         range='0 to Infinity',
         help="set the minimum length a cut can be. If a cut is too short, don't cut")
     ops += add_argument('--combine_files', action='store_true',
@@ -153,7 +165,7 @@ def main_options():
     ops += add_argument('--preview', action='store_true',
         help='show stats on how the input will be cut.')
 
-    ops += add_argument('--frame_margin', '-m', type=int, default=6,
+    ops += add_argument('--frame_margin', '-m', type=frame_type, default=6,
         range='0 to Infinity',
         help='set how many "silent" frames of on either side of "loud" sections be included.')
     ops += add_argument('--silent_threshold', '-t', type=float_type, default=0.04,
@@ -198,10 +210,10 @@ def info_options():
 
     ops += add_argument('--my_ffmpeg', action='store_true',
         help='use your ffmpeg and other binaries instead of the ones packaged.')
-    ops += add_argument('(input)', nargs='*',
-        help='the path to a file you want inspected.')
     ops += add_argument('--help', '-h', action='store_true',
         help='print info about the program or an option and exit.')
+    ops += add_argument('(input)', nargs='*',
+        help='the path to a file you want inspected.')
     return ops
 
 def genHelp(option_data):
@@ -270,7 +282,7 @@ def main():
         sys.exit()
     else:
         option_data = main_options()
-        args = ParseOptions(sys.argv[1:], Log(), option_data)
+        args = ParseOptions(sys.argv[1:], Log(True), option_data)
 
     log = Log(args.debug, args.show_ffmpeg_debug, args.quiet)
     log.debug('')
@@ -426,8 +438,7 @@ def main():
                 # This is the default fps value for Premiere Pro Projects.
                 fps = 29.97
             else:
-                # Grab fps to know what the output video's fps should be.
-                # DaVinci Resolve doesn't need fps, but grab it away just in case.
+                # Don't know the correct fps to set so get the input's
                 fps = ffmpegFPS(ffmpeg, INPUT_FILE, log)
             log.debug(f'ffmpeg fps: {fps}')
 
@@ -447,7 +458,6 @@ def main():
                 log.error("You choose a track that doesn't exist.\n" \
                     f'There {message}.\n {allTracks}')
 
-            # Get video codec
             vcodec = getVideoCodec(INPUT_FILE, ffmpeg, log, args.video_codec)
 
             # Split audio tracks into: 0.wav, 1.wav, etc.
@@ -465,8 +475,7 @@ def main():
                 # Combine all audio tracks into one audio file, then read.
                 cmd = [ffmpeg, '-y', '-i', INPUT_FILE, '-filter_complex',
                     f'[0:a]amix=inputs={tracks}:duration=longest', '-ar',
-                    sampleRate, '-ac', '2', '-f', 'wav', #'-acodec', 'pcm_s16le',
-                    f'{TEMP}/combined.wav']
+                    sampleRate, '-ac', '2', '-f', 'wav', f'{TEMP}/combined.wav']
                 cmd = ffAddDebug(cmd, log.is_ffmpeg)
                 subprocess.call(cmd)
 
@@ -572,7 +581,7 @@ def main():
             fastVideo(INPUT_FILE, chunks, includeFrame, speeds, fps,
             args.machine_readable_progress, args.no_progress, TEMP, log)
             muxVideo(ffmpeg, newOutput, args.keep_tracks_seperate, tracks,
-                args.video_bitrate, args.tune, args.preset, vcodec,
+                args.video_bitrate, args.tune, args.preset, vcodec, args.audio_codec,
                 args.constant_rate_factor, TEMP, log)
 
     if(newOutput is not None and not os.path.isfile(newOutput)):
